#!/usr/bin/env bash
#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

#
#  A file to copy all files from a provided source directory to
#  the Workspaces staging directory for ingestion.
#
#  Arguments:
#       1: The path to the source directory
#       2: The source directory name
#       3: The staging directory root path
#
set -o errexit -o nounset -o xtrace

SRC_PATH=$1;shift
SRC_NAME=$1;shift
STAGE_DIR=$1;shift

SRC_DIR=${SRC_PATH}/${SRC_NAME}

# Create the staging directory carefully:
mkdir -p ${STAGE_DIR}/${SRC_NAME}

# Link all the files over to the staging directory (Create hard link, and be insistent)
#
# We just want the file name, so we'll work in the source directory
pushd ${SRC_DIR}
# link the files
for srcFile in $(ls);do cp ${SRC_DIR}/${srcFile} ${STAGE_DIR}/${SRC_NAME};done
# move back to the working directory
popd
